@@ -1,7 +1,7 @@
 #include "pbc.h"
 #include "get_time.h"
 
-int main()
+int main(void)
 {
     cc_param_t param;
     pairing_t pairing;
