@@ -156,4 +156,21 @@ struct curve_group_data_s {
 typedef struct curve_group_data_s curve_group_data_t[1];
 typedef struct curve_group_data_s *curve_group_data_ptr;
 
+/* these are called in mnt.c */
+void curve_init_cc_j(curve_ptr c, element_ptr j);
+    //assumes j != 0, 1728
+void twist_curve(curve_ptr c);
+    //WARNING: existing points will no longer lie on c
+    //as this modifies c in place
+void compute_trace_n(mpz_t res, mpz_t q, mpz_t trace, int n);
+    //compute trace of Frobenius at q^n given trace at q
+    //see p.105 of Blake, Seroussi and Smart
+
+/* these are called in pairing.c */
+void cc_frobenius(point_ptr r, point_ptr p, mpz_ptr q);
+void curve_init_cc_ab(curve_ptr c, element_ptr a, element_ptr b);
+void cc_init_map_curve(curve_ptr cnew, curve_ptr c,
+                       field_ptr dstfield, fieldmap map);
+void field_init_curve_group(field_t f, curve_t c, mpz_t cofac);
+
 #endif //CURVE_H
