@@ -18,7 +18,7 @@ void darray_init(darray_ptr a)
     a->item = malloc(sizeof(void *) * a->max);
 }
 
-darray_ptr darray_new()
+darray_ptr darray_new(void)
 {
     darray_ptr res = malloc(sizeof(darray_t));
     darray_init(res);
