@@ -176,6 +176,11 @@ static inline int element_length_in_bytes(element_ptr a)
 
 void field_init_fp(field_ptr f, mpz_t prime);
 void element_pow(element_ptr x, element_ptr a, mpz_ptr n);
+void element_pow2(element_ptr x, element_ptr a1, mpz_ptr n1,
+                                 element_ptr a2, mpz_ptr n2);
+void element_pow3(element_ptr x, element_ptr a1, mpz_ptr n1,
+                                 element_ptr a2, mpz_ptr n2,
+                                 element_ptr a3, mpz_ptr n3);
 
 static inline void field_clear(field_ptr f)
 {
