@@ -52,7 +52,7 @@ void pbc_mpz_random(mpz_t z, mpz_t limit)
     current_mpz_random(z, limit, current_random_data);
 }
 
-void random_set_deterministic()
+void random_set_deterministic(void)
 {
     current_mpz_random = deterministic_mpz_random;
     current_random_data = NULL;
@@ -211,6 +211,7 @@ static void fp_tonelli(element_ptr x, element_ptr a)
     element_pow(e0, e0, t);
     mpz_tdiv_q_2exp(e, e, 1);
     element_pow(x, nqr, e);
+    /* TODO: this would be a good place to use element_pow2 ... -hs */
     element_mul(x, x, e0);
     mpz_clear(t);
     mpz_clear(e);
@@ -301,10 +302,16 @@ void element_pow(element_ptr x, element_ptr a, mpz_ptr n)
     int s;
 
     element_t result;
+
+    if (!mpz_sgn(n)) {
+        element_set1(x);
+        return;
+    }
+
     element_init(result, x->field);
     element_set1(result);
 
-    if (mpz_sgn(n)) for (s = mpz_sizeinbase(n, 2) - 1; s >=0; s--) {
+    for (s = mpz_sizeinbase(n, 2) - 1; s >=0; s--) {
 	element_mul(result, result, result);
 	if (mpz_tstbit(n, s)) {
 	    element_mul(result, result, a);
@@ -314,6 +321,97 @@ void element_pow(element_ptr x, element_ptr a, mpz_ptr n)
     element_clear(result);
 }
 
+void element_pow2(element_ptr x, element_ptr a1, mpz_ptr n1,
+                                 element_ptr a2, mpz_ptr n2)
+{
+    int s, s1, s2;
+    int b1, b2;
+
+    element_t result, a1a2;
+
+    if (!mpz_sgn(n1) && !mpz_sgn(n2)) {
+        element_set1(x);
+        return;
+    }
+
+    element_init(result, x->field);
+    element_set1(result);
+
+    element_init(a1a2, x->field);
+    element_mul(a1a2, a1, a2);
+
+    s1 = mpz_sizeinbase(n1, 2) - 1;
+    s2 = mpz_sizeinbase(n2, 2) - 1;
+    for (s = (s1 > s2) ? s1 : s2; s >=0; s--) {
+        element_mul(result, result, result);
+        b1 = mpz_tstbit(n1, s); b2 = mpz_tstbit(n2, s);
+        if (b1 && b2) {
+            element_mul(result, result, a1a2);
+        } else if (b1) {
+            element_mul(result, result, a1);
+        } else if (b2) {
+            element_mul(result, result, a2);
+        }
+    }
+
+    element_set(x, result);
+    element_clear(result);
+    element_clear(a1a2);
+}
+
+void element_pow3(element_ptr x, element_ptr a1, mpz_ptr n1,
+                                 element_ptr a2, mpz_ptr n2,
+                                 element_ptr a3, mpz_ptr n3)
+{
+    int s, s1, s2, s3;
+    int b;
+    int i;
+
+    element_t result;
+    element_t lookup[8];
+
+    if (!mpz_sgn(n1) && !mpz_sgn(n2) && !mpz_sgn(n3)) {
+        element_set1(x);
+        return;
+    }
+
+    element_init(result, x->field);
+    element_set1(result);
+
+    for (i=0; i<8; i++)
+        element_init(lookup[i], x->field);
+
+    /* build lookup table. */
+    element_set1(lookup[0]);
+    element_set(lookup[1], a1);
+    element_set(lookup[2], a2);
+    element_set(lookup[4], a3);
+    element_mul(lookup[3], a1, a2);
+    element_mul(lookup[5], a1, a3);
+    element_mul(lookup[6], a2, a3);
+    element_mul(lookup[7], lookup[6], a1);
+
+    /* calculate largest exponent bitsize */
+    s1 = mpz_sizeinbase(n1, 2) - 1;
+    s2 = mpz_sizeinbase(n2, 2) - 1;
+    s3 = mpz_sizeinbase(n3, 2) - 1;
+    s = (s1 > s2) ? ((s1 > s3) ? s1 : s3)
+                    : ((s2 > s3) ? s2 : s3);
+
+    for (; s >=0; s--) {
+        element_mul(result, result, result);
+        b = (mpz_tstbit(n1, s))
+          + (mpz_tstbit(n2, s) << 1)
+          + (mpz_tstbit(n3, s) << 2);
+        element_mul(result, result, lookup[b]);
+    }
+    
+    element_set(x, result);
+    element_clear(result);
+    for (i=0; i<8; i++)
+        element_clear(lookup[i]);
+}
+
 element_ptr field_get_nqr(field_ptr f)
 {
     if (!f->nqr) {
