@@ -588,7 +588,7 @@ int mnt_step2(darray_ptr L, int D, mpz_t U)
     return 0;
 }
 
-int find_mnt6_curve(darray_t L, int D, int bitlimit)
+int find_mnt6_curve(darray_t L, int D, unsigned bitlimit)
 {
     //first solve DV^2 = 3l^2 - 2l + 3
     //use variable subst U = 3l - 1 to transform equation
