@@ -20,6 +20,6 @@ void cm_info_init(cm_info_t cm);
 void cm_info_clear(cm_info_t cm);
 
 void compute_cm_curve(cc_param_ptr cc, cm_info_ptr cm);
-int find_mnt6_curve(darray_t L, int D, int bitlimit);
+int find_mnt6_curve(darray_t L, int D, unsigned bitlimit);
 
 #endif //MNT_H
