@@ -363,7 +363,7 @@ static void cc_miller_no_denom(element_t res, mpz_t q, point_t P,
     element_t t0;
     element_t e0, e1;
 
-    void do_vertical()
+    void do_vertical(void)
     {
 	if (point_is_inf(Z)) {
 	    return;
@@ -373,7 +373,7 @@ static void cc_miller_no_denom(element_t res, mpz_t q, point_t P,
 	element_mul(v, v, e0);
     }
 
-    void do_tangent()
+    void do_tangent(void)
     {
 	//a = -slope_tangent(Z.x, Z.y);
 	//b = 1;
@@ -422,7 +422,7 @@ static void cc_miller_no_denom(element_t res, mpz_t q, point_t P,
 	element_mul(v, v, e0);
     }
 
-    void do_line()
+    void do_line(void)
     {
 	//a = -(B.y - A.y) / (B.x - A.x);
 	//b = 1;
@@ -748,7 +748,7 @@ static void solinas_pairing(element_ptr out, element_ptr in1, element_ptr in2,
     element_ptr Qx = ((point_ptr) in2->data)->x;
     element_ptr Qy = ((point_ptr) in2->data)->y;
 
-    void do_tangent() {
+    void do_tangent(void) {
 	//a = -slope_tangent(V.x, V.y);
 	//b = 1;
 	//c = -(V.y + aV.x);
