@@ -1,7 +1,7 @@
 #ifndef SOLINAS_H
 #define SOLINAS_H
 
-#include "fieldi.h"
+#include "fieldquadratic.h"
 
 struct solinas_param_s {
     int exp2;
