@@ -1,7 +1,7 @@
 //Boneh-Boyen signatures demo
 #include "sig.h"
 
-int main()
+int main(void)
 {
     cc_param_t cc_param;
     pairing_t pairing;
