@@ -2,7 +2,7 @@
 //This one uses the signature library and is more realistic
 #include "sig.h"
 
-int main()
+int main(void)
 {
     cc_param_t cc_param;
     pairing_t pairing;
