@@ -5,7 +5,7 @@
 //is faster than to G2, and this has to be done often.
 #include "pbc.h"
 
-int main()
+int main(void)
 {
     cc_param_t param;
     element_t g, h, s;
