@@ -1,6 +1,6 @@
 #include "pbc.h"
 
-int main()
+int main(void)
 {
     darray_t L;
     cc_param_t param;
@@ -18,7 +18,7 @@ int main()
     fprintf(stderr, "Computing Hilbert polynomial...\n");
     compute_cm_curve(param, cm);
     fprintf(stderr, "done\n");
-    fprintf(stderr, "bits in q = %d\n", mpz_sizeinbase(cm->q, 2));
+    fprintf(stderr, "bits in q = %zu\n", mpz_sizeinbase(cm->q, 2));
     cc_param_out_str(stdout, param);
 
     return 0;
