@@ -1,7 +1,7 @@
 //Boneh-Lynn-Shacham short signatures demo
 #include "pbc.h"
 
-int main()
+int main(void)
 {
     cc_param_t param;
     element_t g, h, s;
